@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -26,7 +26,6 @@ CKEDITOR.editorConfig = function( config ) {
 		'entities,' +
 		'filebrowser,' +
 		'find,' +
-		'flash,' +
 		'floatingspace,' +
 		'font,' +
 		'format,' +
@@ -47,8 +46,10 @@ CKEDITOR.editorConfig = function( config ) {
 		'newpage,' +
 		'pagebreak,' +
 		'pastefromgdocs,' +
+		'pastefromlibreoffice,' +
 		'pastefromword,' +
 		'pastetext,' +
+		'editorplaceholder,' +
 		'preview,' +
 		'print,' +
 		'removeformat,' +
