@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -289,7 +289,8 @@ CKEDITOR.config = {
 	 * reflect the CSS used in the target pages where the content is to be
 	 * displayed.
 	 *
-	 * **Note:** This configuration value is ignored by {@glink guide/dev_inline inline editor}
+	 * **Note:** This configuration value is used only in {@glink guide/dev_framed `<iframe>`-based editor }
+	 * and ignored by {@glink guide/dev_inline inline editor}
 	 * as it uses the styles that come directly from the page that CKEditor is
 	 * rendered on. It is also ignored in the {@link #fullPage full page mode} in
 	 * which the developer has full control over the page HTML code.
@@ -368,6 +369,22 @@ CKEDITOR.config = {
 	 */
 	tabIndex: 0,
 
+	/**
+	 * Indicates that some of the editor features, like alignment and text
+	 * direction, should use the "computed value" of the feature to indicate its
+	 * on/off state instead of using the "real value".
+	 *
+	 * If enabled in a Left-To-Right written document, the "Left Justify"
+	 * alignment button will be shown as active, even if the alignment style is not
+	 * explicitly applied to the current paragraph in the editor.
+	 *
+	 *		config.useComputedState = false;
+	 *
+	 * @since 3.4.0
+	 * @cfg {Boolean} [useComputedState=true]
+	 */
+	useComputedState: true,
+
 	/**
 	 * The editor UI outer width. This configuration option accepts an integer
 	 * (to denote a value in pixels) or any CSS-defined length unit.
@@ -417,21 +434,6 @@ CKEDITOR.config = {
 	]
 };
 
-/**
- * Indicates that some of the editor features, like alignment and text
- * direction, should use the "computed value" of the feature to indicate its
- * on/off state instead of using the "real value".
- *
- * If enabled in a Left-To-Right written document, the "Left Justify"
- * alignment button will be shown as active, even if the alignment style is not
- * explicitly applied to the current paragraph in the editor.
- *
- *		config.useComputedState = false;
- *
- * @since 3.4.0
- * @cfg {Boolean} [useComputedState=true]
- */
-
 /**
  * The base user interface color to be used by the editor. Not all skins are
  * {@glink guide/skin_sdk_chameleon compatible with this setting}.
