@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -206,3 +206,33 @@ CKEDITOR.EVENT_PHASE_AT_TARGET = 2;
  * @member CKEDITOR
  */
 CKEDITOR.EVENT_PHASE_BUBBLING = 3;
+
+/**
+ * Integration with browser's "Go back" and "Go forward" buttons using Native History API.
+ *
+ * @since 4.17.0
+ * @readonly
+ * @property {Number} [=1]
+ * @member CKEDITOR
+ */
+CKEDITOR.HISTORY_NATIVE = 1;
+
+/**
+ * Integration with browser's "Go back" and "Go forward" buttons using hash-based navigation.
+ *
+ * @since 4.17.0
+ * @readonly
+ * @property {Number} [=2]
+ * @member CKEDITOR
+ */
+CKEDITOR.HISTORY_HASH = 2;
+
+/**
+ * Switch off integration with browser's "Go back" and "Go forward" buttons.
+ *
+ * @since 4.17.0
+ * @readonly
+ * @property {Number} [=0]
+ * @member CKEDITOR
+ */
+CKEDITOR.HISTORY_OFF = 0;
