@@ -1,9 +1,11 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
 ( function() {
+	var removeReservedKeywords;
+
 	/**
 	 * Represents an HTML data processor, which is responsible for translating and
 	 * transforming the editor data on input and output.
@@ -48,17 +50,18 @@
 		htmlFilter.addRules( createBogusAndFillerRules( editor, 'html' ), { applyToAll: true } );
 
 		editor.on( 'toHtml', function( evt ) {
-			var evtData = evt.data,
+			var randomNumber = generateRandomNumber(),
+				evtData = evt.data,
 				data = evtData.dataValue,
 				fixBodyTag;
 
-			// Before we start protecting markup, make sure there's no externally injected <cke:encoded> elements. Only
-			// HTML processor can use this tag, any external injections should discarded.
-			data = data.replace( reservedElementsRegex, '' );
+			// Before we start protecting markup, make sure there are no externally injected
+			// protection keywords.
+			data = removeReservedKeywords( data );
 
 			// The source data is already HTML, but we need to clean
 			// it up and apply the filter.
-			data = protectSource( data, editor );
+			data = protectSource( data, editor, randomNumber );
 
 			// Protect content of textareas. (https://dev.ckeditor.com/ticket/9995)
 			// Do this before protecting attributes to avoid breaking:
@@ -68,7 +71,7 @@
 			// Before anything, we must protect the URL attributes as the
 			// browser may changing them when setting the innerHTML later in
 			// the code.
-			data = protectAttributes( data );
+			data = protectAttributes( data, randomNumber );
 
 			// Protect elements than can't be set inside a DIV. E.g. IE removes
 			// style tags from innerHTML. (https://dev.ckeditor.com/ticket/3710)
@@ -88,7 +91,7 @@
 
 			// There are attributes which may execute JavaScript code inside fixBin.
 			// Encode them greedily. They will be unprotected right after getting HTML from fixBin. (https://dev.ckeditor.com/ticket/10)
-			data = protectInsecureAttributes( data );
+			data = protectInsecureAttributes( data, randomNumber );
 
 			var fixBin = evtData.context || editor.editable().getName(),
 				isPre;
@@ -108,7 +111,7 @@
 			data = el.getHtml().substr( 1 );
 
 			// Restore shortly protected attribute names.
-			data = data.replace( new RegExp( 'data-cke-' + CKEDITOR.rnd + '-', 'ig' ), '' );
+			data = data.replace( new RegExp( 'data-cke-' + randomNumber + '-', 'ig' ), '' );
 
 			isPre && ( data = data.replace( /^<pre>|<\/pre>$/gi, '' ) );
 
@@ -301,6 +304,33 @@
 				context: context,
 				enterMode: enterMode || this.editor.enterMode
 			} ).dataValue;
+		},
+
+		/**
+		 * @since 4.16.1
+		 * @private
+		 * @param {String} data
+		 */
+		protectSource: function( data ) {
+			return protectSource( data, this.editor );
+		},
+
+		/**
+		 * @since 4.16.1
+		 * @private
+		 * @param {String} html
+		 */
+		unprotectSource: function( html ) {
+			return unprotectSource( html, this.editor );
+		},
+
+		/**
+		 * @since 4.16.2
+		 * @private
+		 * @param {String} html
+		 */
+		unprotectRealComments: function( html ) {
+			return unprotectRealComments( html );
 		}
 	};
 
@@ -801,8 +831,7 @@
 		// Note: we use lazy star '*?' to prevent eating everything up to the last occurrence of </style> or </textarea>.
 	var protectElementsRegex = /(?:<style(?=[ >])[^>]*>[\s\S]*?<\/style>)|(?:<(:?link|meta|base)[^>]*>)/gi,
 		protectTextareaRegex = /(<textarea(?=[ >])[^>]*>)([\s\S]*?)(?:<\/textarea>)/gi,
-		encodedElementsRegex = /<cke:encoded>([^<]*)<\/cke:encoded>/gi,
-		reservedElementsRegex = createReservedElementsRegex();
+		encodedElementsRegex = /<cke:encoded>([^<]*)<\/cke:encoded>/gi;
 
 		// Element name should be followed by space or closing angle bracket '>' to not protect custom tags (#988).
 	var protectElementNamesRegex = /(<\/?)((?:object|embed|param|html|body|head|title)([\s][^>]*)?>)/gi,
@@ -810,13 +839,13 @@
 
 	var protectSelfClosingRegex = /<cke:(param|embed)([^>]*?)\/?>(?!\s*<\/cke:\1)/gi;
 
-	function protectAttributes( html ) {
+	function protectAttributes( html, randomNumber ) {
 		return html.replace( protectElementRegex, function( element, tag, attributes ) {
 			return '<' + tag + attributes.replace( protectAttributeRegex, function( fullAttr, attrName ) {
 				// Avoid corrupting the inline event attributes (https://dev.ckeditor.com/ticket/7243).
 				// We should not rewrite the existed protected attributes, e.g. clipboard content from editor. (https://dev.ckeditor.com/ticket/5218)
 				if ( protectAttributeNameRegex.test( attrName ) && attributes.indexOf( 'data-cke-saved-' + attrName ) == -1 )
-					return ' data-cke-saved-' + fullAttr + ' data-cke-' + CKEDITOR.rnd + '-' + fullAttr;
+					return ' data-cke-saved-' + fullAttr + ' data-cke-' + randomNumber + '-' + fullAttr;
 
 				return fullAttr;
 			} ) + '>';
@@ -865,78 +894,12 @@
 		} );
 	}
 
-	// Produces regex matching reserved `cke:encoded` element for valid HTML symbol codes.
-	// Matches `cke:encoded` element in hexadecimal, HTML-code, or HTML-entity.
-	function createReservedElementsRegex() {
-		return new RegExp( '(' +
-			// Create closed element regex i.e `<cke:encoded>xxx</cke:encoded>`.
-			createEncodedRegex( '<cke:encoded>' ) +
-			'(.*?)' +
-			createEncodedRegex( '</cke:encoded>' ) +
-			')|(' +
-			// Create unclosed element regex i.e `<cke:encoded>xxx` or `xxx</cke:encoded>` to make sure that
-			// element won't be closed by HTML parser and matched by `unprotectElements` function.
-			createEncodedRegex( '<' ) +
-			createEncodedRegex( '/' ) + '?' +
-			createEncodedRegex( 'cke:encoded>' ) +
-			')', 'gi' );
-	}
-
-	function createEncodedRegex( str ) {
-		return CKEDITOR.tools.array.reduce( str.split( '' ), function( cur, character ) {
-			// Produce case insensitive regex. `i` flag is not enough thus code entities differs
-			// depending on case sensitivity.
-			var lowerCase = character.toLowerCase(),
-				upperCase = character.toUpperCase(),
-				regex = createCharacterEncodedRegex( lowerCase );
-
-			if ( lowerCase !== upperCase ) {
-				regex += '|' + createCharacterEncodedRegex( upperCase );
-			}
-
-			cur += '(' + regex + ')';
-
-			return cur;
-		}, '' );
-	}
-
-	function createCharacterEncodedRegex( character ) {
-		var map = getCharRegexMap( character ),
-			charRegex = character;
-
-		for ( var code in map ) {
-			if ( map[ code ] ) {
-				charRegex += '|' + map[ code ];
-			}
-		}
-
-		return charRegex;
-	}
-
-	function getCharRegexMap( character ) {
-		var entities = {
-				'<': '&lt;',
-				'>': '&gt;',
-				':': '&colon;'
-			},
-			charCode = character.charCodeAt( 0 ),
-			hex = charCode.toString( 16 );
-
-		return {
-			// `;` is optional and HTML parser is able to recognize codes without it.
-			htmlCode: '&#' + charCode + ';?',
-			// Hexadecimal value is valid despite leading zero padding e.g. `&#x0065` === `&#x65`.
-			hex: '&#x0*' + hex + ';?',
-			entity: entities[ character ]
-		};
-	}
-
 	// Replace all "on\w{3,}" strings which are not:
 	// * opening tags - e.g. `<onfoo`,
 	// * closing tags - e.g. </onfoo> (tested in "false positive 1"),
 	// * part of other attribute - e.g. `data-onfoo` or `fonfoo`.
-	function protectInsecureAttributes( html ) {
-		return html.replace( /([^a-z0-9<\-])(on\w{3,})(?!>)/gi, '$1data-cke-' + CKEDITOR.rnd + '-$2' );
+	function protectInsecureAttributes( html, randomNumber ) {
+		return html.replace( /([^a-z0-9<\-])(on\w{3,})(?!>)/gi, '$1data-cke-' + randomNumber + '-$2' );
 	}
 
 	function unprotectRealComments( html ) {
@@ -955,11 +918,11 @@
 		} );
 	}
 
-	function protectSource( data, editor ) {
+	function protectSource( data, editor, randomNumber ) {
 		var protectedHtml = [],
 			protectRegexes = editor.config.protectedSource,
 			store = editor._.dataStore || ( editor._.dataStore = { id: 1 } ),
-			tempRegex = /<\!--\{cke_temp(comment)?\}(\d*?)-->/g;
+			tempRegex = new RegExp('<\\!--\\{cke_temp_' + randomNumber + '(comment)?\\}(\\d*?)-->', 'g' );
 
 		var regexes = [
 			// Script tags will also be forced to be protected, otherwise
@@ -978,7 +941,7 @@
 		// Note that we use a different tag for comments, as we need to
 		// transform them when applying filters.
 		data = data.replace( ( /<!--[\s\S]*?-->/g ), function( match ) {
-			return '<!--{cke_tempcomment}' + ( protectedHtml.push( match ) - 1 ) + '-->';
+			return '<!--{cke_temp_' + randomNumber + 'comment}' + ( protectedHtml.push( match ) - 1 ) + '-->';
 		} );
 
 		for ( var i = 0; i < regexes.length; i++ ) {
@@ -989,7 +952,8 @@
 				} );
 
 				// Avoid protecting over protected, e.g. /\{.*?\}/
-				return ( /cke_temp(comment)?/ ).test( match ) ? match : '<!--{cke_temp}' + ( protectedHtml.push( match ) - 1 ) + '-->';
+				return ( tempRegex ).test( match ) ? match : '<!--{cke_temp_' + randomNumber + '}' +
+					( protectedHtml.push( match ) - 1 ) + '-->';
 			} );
 		}
 		data = data.replace( tempRegex, function( $, isComment, id ) {
@@ -1027,6 +991,134 @@
 			root.add( fixBodyElement );
 		}
 	}
+
+	// Removes reserved htmldataprocessor keywords ensuring that they are only used internally.
+	// This function produces very complicated regex code. Using IIFE ensures that the regex
+	// is build only once for this module.
+	removeReservedKeywords = ( function() {
+		var regexes = [
+			createEncodedKeywordRegex(),
+			createSourceKeywordRegex(),
+			createIncorrectCommentRegex()
+		];
+
+		return function( data ) {
+			while( isContentMatchingAnyPattern( regexes, data ) ) {
+				data = removeMatchingContent( regexes, data );
+			}
+
+			return data;
+		};
+
+		function isContentMatchingAnyPattern( regexes, data ) {
+			for ( var i = 0; i < regexes.length; i++ ) {
+				var regex = regexes[ i ];
+
+				regex.lastIndex = 0;
+
+				if ( regex.test( data ) ) {
+					return true;
+				}
+			}
+
+			return false;
+		}
+
+		function removeMatchingContent( regexes, data ) {
+			for ( var i = 0; i < regexes.length; i++ ) {
+				data = data.replace( regexes[ i ], '' );
+			}
+			return data;
+		}
+
+		function createIncorrectCommentRegex() {
+			return /<!(?:\s*-\s*){2,3}!?\s*>/g;
+		}
+
+		// Produces regex matching `cke:encoded` element.
+		function createEncodedKeywordRegex() {
+			return new RegExp( '(' +
+				// Create closed element regex i.e `<cke:encoded>xxx</cke:encoded>`.
+				createEncodedRegex( '<cke:encoded>' ) +
+				'(.*?)' +
+				createEncodedRegex( '</cke:encoded>' ) +
+				')|(' +
+				// Create unclosed element regex i.e `<cke:encoded>xxx` or `xxx</cke:encoded>` to make sure that
+				// element won't be closed by HTML parser and matched by `unprotectElements` function.
+				createEncodedRegex( '<' ) +
+				createEncodedRegex( '/' ) + '?' +
+				createEncodedRegex( 'cke:encoded>' ) +
+				')', 'gi' );
+		}
+
+		// Produces regex matching `{cke_protected}` and `{cke_protected_id}` keywords.
+		function createSourceKeywordRegex() {
+			return new RegExp( '((' +
+				createEncodedRegex( '{cke_protected' ) +
+				')(_[0-9]*)?' +
+				createEncodedRegex( '}' ) +
+				')' , 'gi' );
+		}
+
+		function createEncodedRegex( str ) {
+			return CKEDITOR.tools.array.reduce( str.split( '' ), function( cur, character ) {
+				// Produce case insensitive regex. `i` flag is not enough thus code entities differs
+				// depending on case sensitivity.
+				var lowerCase = character.toLowerCase(),
+					upperCase = character.toUpperCase(),
+					regex = createCharacterEncodedRegex( lowerCase );
+
+				if ( lowerCase !== upperCase ) {
+					regex += '|' + createCharacterEncodedRegex( upperCase );
+				}
+
+				cur += '(' + regex + ')';
+
+				return cur;
+			}, '' );
+		}
+
+		function createCharacterEncodedRegex( character ) {
+			var map = getCharRegexMap( character ),
+				charRegex = character;
+
+			for ( var code in map ) {
+				if ( map[ code ] ) {
+					charRegex += '|' + map[ code ];
+				}
+			}
+
+			return charRegex;
+		}
+
+		function getCharRegexMap( character ) {
+			var entities = {
+				'<': '&lt;',
+				'>': '&gt;',
+				':': '&colon;'
+			},
+				charCode = character.charCodeAt( 0 ),
+				hex = charCode.toString( 16 );
+
+			return {
+				// `;` is optional and HTML parser is able to recognize codes without it.
+				htmlCode: '&#' + charCode + ';?',
+				// Hexadecimal value is valid despite leading zero padding e.g. `&#x0065` === `&#x65`.
+				hex: '&#x0*' + hex + ';?',
+				entity: entities[ character ]
+			};
+		}
+	} )();
+
+	function generateRandomNumber() {
+		var cryptoApi = window.crypto || window.msCrypto;
+
+		if ( cryptoApi ) {
+			return cryptoApi.getRandomValues( new Uint32Array( 1 ) )[ 0 ];
+		}
+
+		return Math.floor( Math.random() *  9000000000 + 1000000000 );
+	}
 } )();
 
 /**
