@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -34,7 +34,29 @@
 		 */
 		type: CKEDITOR.NODE_TEXT,
 
-		filter: function() {},
+		filter: function( filter ) {
+			var style = this.getAscendant( 'style' );
+
+			if ( !style ) {
+				return;
+			}
+
+			// MathML and SVG namespaces processing parsers `style` content as a normal HTML, not text.
+			// Make sure to filter such content also.
+			var nonHtmlElementNamespace = style.getAscendant( { math: 1, svg: 1 } );
+
+			if ( !nonHtmlElementNamespace ) {
+				return;
+			}
+
+			var fragment = CKEDITOR.htmlParser.fragment.fromHtml( this.value ),
+				writer = new CKEDITOR.htmlParser.basicWriter();
+
+			filter.applyTo( fragment );
+			fragment.writeHtml( writer );
+
+			this.value = writer.getHtml();
+		},
 
 		/**
 		 * Writes the CDATA with no special manipulations.
