@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -19,6 +19,7 @@
  */
 CKEDITOR.lang[ 'bg' ] = {
 	// ARIA description.
+	application: 'Rich Text Editor', // MISSING
 	editor: 'Редактор за форматиран текст',
 	editorPanel: 'Панел на текстовия редактор',
 
@@ -34,7 +35,6 @@ CKEDITOR.lang[ 'bg' ] = {
 		upload: 'Качване',
 		uploadSubmit: 'Изпращане към сървъра',
 		image: 'Изображение',
-		flash: 'Флаш',
 		form: 'Форма',
 		checkbox: 'Поле за избор',
 		radio: 'Радио бутон',
