@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -19,6 +19,7 @@
  */
 CKEDITOR.lang[ 'ca' ] = {
 	// ARIA description.
+	application: 'Rich Text Editor', // MISSING
 	editor: 'Editor de text enriquit',
 	editorPanel: 'Panell de l\'editor de text enriquit',
 
@@ -34,7 +35,6 @@ CKEDITOR.lang[ 'ca' ] = {
 		upload: 'Puja',
 		uploadSubmit: 'Envia-la al servidor',
 		image: 'Imatge',
-		flash: 'Flash',
 		form: 'Formulari',
 		checkbox: 'Casella de verificació',
 		radio: 'Botó d\'opció',
