@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -19,7 +19,8 @@
  */
 CKEDITOR.lang[ 'it' ] = {
 	// ARIA description.
-	editor: 'Rich Text Editor',
+	application: 'Rich Text Editor',
+	editor: 'Editor',
 	editorPanel: 'Pannello Rich Text Editor',
 
 	// Common messages and labels.
@@ -34,7 +35,6 @@ CKEDITOR.lang[ 'it' ] = {
 		upload: 'Carica',
 		uploadSubmit: 'Invia al server',
 		image: 'Immagine',
-		flash: 'Oggetto Flash',
 		form: 'Modulo',
 		checkbox: 'Checkbox',
 		radio: 'Radio Button',
