@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -19,6 +19,7 @@
  */
 CKEDITOR.lang[ 'ka' ] = {
 	// ARIA description.
+	application: 'Rich Text Editor', // MISSING
 	editor: 'ტექსტის რედაქტორი',
 	editorPanel: 'Rich Text Editor panel', // MISSING
 
@@ -34,7 +35,6 @@ CKEDITOR.lang[ 'ka' ] = {
 		upload: 'ატვირთვა',
 		uploadSubmit: 'სერვერზე გაგზავნა',
 		image: 'სურათი',
-		flash: 'Flash',
 		form: 'ფორმა',
 		checkbox: 'მონიშვნის ღილაკი',
 		radio: 'ამორჩევის ღილაკი',
