@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -18,7 +18,8 @@
  */
 CKEDITOR.lang[ 'mk' ] = {
 	// ARIA description.
-	editor: 'Rich Text Editor', // MISSING
+	application: 'Rich Text Editor', // MISSING
+	editor: 'Editor', // MISSING
 	editorPanel: 'Rich Text Editor panel', // MISSING
 
 	// Common messages and labels.
@@ -33,7 +34,6 @@ CKEDITOR.lang[ 'mk' ] = {
 		upload: 'Прикачи',
 		uploadSubmit: 'Прикачи на сервер',
 		image: 'Слика',
-		flash: 'Flash', // MISSING
 		form: 'Form', // MISSING
 		checkbox: 'Checkbox', // MISSING
 		radio: 'Radio Button', // MISSING
