@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -18,7 +18,8 @@
  */
 CKEDITOR.lang[ 'pt-br' ] = {
 	// ARIA description.
-	editor: 'Editor de Rich Text',
+	application: 'Editor de Rich Text',
+	editor: 'Editor',
 	editorPanel: 'Painel do editor de Rich Text',
 
 	// Common messages and labels.
@@ -33,7 +34,6 @@ CKEDITOR.lang[ 'pt-br' ] = {
 		upload: 'Enviar ao Servidor',
 		uploadSubmit: 'Enviar para o Servidor',
 		image: 'Imagem',
-		flash: 'Flash',
 		form: 'Formulário',
 		checkbox: 'Caixa de Seleção',
 		radio: 'Botão de Opção',
@@ -111,30 +111,30 @@ CKEDITOR.lang[ 'pt-br' ] = {
 			35: 'End',
 			36: 'Home',
 			46: 'Delete',
-			112: 'F1', // MISSING
-			113: 'F2', // MISSING
-			114: 'F3', // MISSING
-			115: 'F4', // MISSING
-			116: 'F5', // MISSING
-			117: 'F6', // MISSING
-			118: 'F7', // MISSING
-			119: 'F8', // MISSING
-			120: 'F9', // MISSING
-			121: 'F10', // MISSING
-			122: 'F11', // MISSING
-			123: 'F12', // MISSING
-			124: 'F13', // MISSING
-			125: 'F14', // MISSING
-			126: 'F15', // MISSING
-			127: 'F16', // MISSING
-			128: 'F17', // MISSING
-			129: 'F18', // MISSING
-			130: 'F19', // MISSING
-			131: 'F20', // MISSING
-			132: 'F21', // MISSING
-			133: 'F22', // MISSING
-			134: 'F23', // MISSING
-			135: 'F24', // MISSING
+			112: 'F1',
+			113: 'F2',
+			114: 'F3',
+			115: 'F4',
+			116: 'F5',
+			117: 'F6',
+			118: 'F7',
+			119: 'F8',
+			120: 'F9',
+			121: 'F10',
+			122: 'F11',
+			123: 'F12',
+			124: 'F13',
+			125: 'F14',
+			126: 'F15',
+			127: 'F16',
+			128: 'F17',
+			129: 'F18',
+			130: 'F19',
+			131: 'F20',
+			132: 'F21',
+			133: 'F22',
+			134: 'F23',
+			135: 'F24',
 			224: 'Comando'
 		},
 
