@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -18,6 +18,7 @@
  */
 CKEDITOR.lang[ 'si' ] = {
 	// ARIA description.
+	application: 'Rich Text Editor', // MISSING
 	editor: 'පොහොසත් වචන සංස්කරණ',
 	editorPanel: 'Rich Text Editor panel', // MISSING
 
@@ -33,7 +34,6 @@ CKEDITOR.lang[ 'si' ] = {
 		upload: 'උඩුගතකිරීම',
 		uploadSubmit: 'සේවාදායකය වෙත යොමුකිරිම',
 		image: 'රුපය',
-		flash: 'දීප්තිය',
 		form: 'පෝරමය',
 		checkbox: 'ලකුණුකිරීමේ කොටුව',
 		radio: 'තේරීම් ',
