@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -19,6 +19,7 @@
  */
 CKEDITOR.lang[ 'sl' ] = {
 	// ARIA description.
+	application: 'Rich Text Editor', // MISSING
 	editor: 'Urejevalnik obogatenega besedila',
 	editorPanel: 'Plošča urejevalnika obogatenega besedila',
 
@@ -34,7 +35,6 @@ CKEDITOR.lang[ 'sl' ] = {
 		upload: 'Naloži',
 		uploadSubmit: 'Pošlji na strežnik',
 		image: 'Slika',
-		flash: 'Flash',
 		form: 'Obrazec',
 		checkbox: 'Potrditveno polje',
 		radio: 'Izbirno polje',
