@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -19,7 +19,8 @@
  */
 CKEDITOR.lang[ 'sr-latn' ] = {
 	// ARIA description.
-	editor: 'Bogati uređivač teksta',
+	application: 'Uređivač bogatog teksta',
+	editor: 'Uređivač ',
 	editorPanel: 'Bogati uređivač panel',
 
 	// Common messages and labels.
@@ -34,7 +35,6 @@ CKEDITOR.lang[ 'sr-latn' ] = {
 		upload: 'Pošalji',
 		uploadSubmit: 'Pošalji na server',
 		image: 'Slika',
-		flash: 'Fleš',
 		form: 'Formular',
 		checkbox: 'Polje za potvrdu',
 		radio: 'Radio-dugme',
