@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -19,7 +19,8 @@
  */
 CKEDITOR.lang[ 'sr' ] = {
 	// ARIA description.
-	editor: 'ХТМЛ уређивач текста',
+	application: 'Уређивач богатог текста',
+	editor: 'Уређивач',
 	editorPanel: 'ХТМЛ уређивач панел',
 
 	// Common messages and labels.
@@ -34,7 +35,6 @@ CKEDITOR.lang[ 'sr' ] = {
 		upload: 'Пошаљи',
 		uploadSubmit: 'Пошаљи на сервер',
 		image: 'Слика',
-		flash: 'Флеш елемент',
 		form: 'Формулар',
 		checkbox: 'Поље за потврду',
 		radio: 'Радио-дугме',
