@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -18,6 +18,7 @@
  */
 CKEDITOR.lang[ 'sv' ] = {
 	// ARIA description.
+	application: 'Rich Text Editor', // MISSING
 	editor: 'Rich Text-editor',
 	editorPanel: 'Panel till Rich Text-editor',
 
@@ -33,7 +34,6 @@ CKEDITOR.lang[ 'sv' ] = {
 		upload: 'Ladda upp',
 		uploadSubmit: 'Skicka till server',
 		image: 'Bild',
-		flash: 'Flash',
 		form: 'Formulär',
 		checkbox: 'Kryssruta',
 		radio: 'Alternativknapp',
