@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -18,6 +18,7 @@
  */
 CKEDITOR.lang[ 'tr' ] = {
 	// ARIA description.
+	application: 'Rich Text Editor', // MISSING
 	editor: 'Zengin Metin Editörü',
 	editorPanel: 'Zengin Metin Editör Paneli',
 
@@ -33,7 +34,6 @@ CKEDITOR.lang[ 'tr' ] = {
 		upload: 'Karşıya Yükle',
 		uploadSubmit: 'Sunucuya Gönder',
 		image: 'Resim',
-		flash: 'Flash',
 		form: 'Form',
 		checkbox: 'Seçim Kutusu',
 		radio: 'Seçenek Düğmesi',
