@@ -1,10 +1,10 @@
 /*
-Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or http://ckeditor.com/license
+Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
+For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'basicstyles', 'bn', {
 	bold: 'বোল্ড',
-	italic: 'ইটালিক',
+	italic: 'বাঁকা',
 	strike: 'স্ট্রাইক থ্রু',
 	subscript: 'অধোলেখ',
 	superscript: 'অভিলেখ',
