@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'clipboard', 'sr-latn', {
@@ -10,5 +10,7 @@ CKEDITOR.plugins.setLang( 'clipboard', 'sr-latn', {
 	paste: 'Zalepi',
 	pasteNotification: '"Pritisnite taster %1 za lepljenje. Vaš pretraživač ne dozvoljava lepljenje iz alatne trake ili menia.',
 	pasteArea: 'Prostor za lepljenje',
-	pasteMsg: 'Nalepite sadržaj u sledeći prostor i pritisnite taster OK.'
+	pasteMsg: 'Nalepite sadržaj u sledeći prostor i pritisnite taster OK.',
+	fileFormatNotSupportedNotification: 'Formati datoteke ${formats} nisu podržani.',
+	fileWithoutFormatNotSupportedNotification: 'Format datoteke nije podržan.'
 } );
