@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'clipboard', 'sv', {
@@ -10,5 +10,7 @@ CKEDITOR.plugins.setLang( 'clipboard', 'sv', {
 	paste: 'Klistra in',
 	pasteNotification: 'Tryck på %1 för att klistra in. Din webbläsare stödjer inte inklistring via verktygsfältet eller snabbmenyn.',
 	pasteArea: 'Inklistringsområde',
-	pasteMsg: 'Klistra in ditt innehåll i området nedan och tryck på OK.'
+	pasteMsg: 'Klistra in ditt innehåll i området nedan och tryck på OK.',
+	fileFormatNotSupportedNotification: 'The ${formats} file format(s) are not supported.', // MISSING
+	fileWithoutFormatNotSupportedNotification: 'The file format is not supported.' // MISSING
 } );
