@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'clipboard', 'zh-cn', {
@@ -10,5 +10,7 @@ CKEDITOR.plugins.setLang( 'clipboard', 'zh-cn', {
 	paste: '粘贴',
 	pasteNotification: '您的浏览器不支持通过工具栏或右键菜单进行粘贴，请按 %1 进行粘贴。',
 	pasteArea: '粘贴区域',
-	pasteMsg: '将您的内容粘贴到下方区域，然后按确定。'
+	pasteMsg: '将您的内容粘贴到下方区域，然后按确定。',
+	fileFormatNotSupportedNotification: 'The ${formats} file format(s) are not supported.', // MISSING
+	fileWithoutFormatNotSupportedNotification: 'The file format is not supported.' // MISSING
 } );
