@@ -1,5 +1,5 @@
-/**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+﻿/**
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -8,7 +8,7 @@
 
 	var stylesLoaded = false,
 		arrTools = CKEDITOR.tools.array,
-		htmlEncode = CKEDITOR.tools.htmlEncode,
+		htmlEncode = CKEDITOR.tools.htmlEncodeAttr,
 		EmojiDropdown = CKEDITOR.tools.createClass( {
 			$: function( editor, plugin ) {
 				var lang = this.lang = editor.lang.emoji,
@@ -186,6 +186,9 @@
 				createEmojiBlock: function() {
 					var output = [];
 
+					// (#2607)
+					this.loadSVGNavigationIcons();
+
 					output.push( this.createGroupsNavigation() );
 					output.push( this.createSearchSection() );
 					output.push( this.createEmojiListBlock() );
@@ -196,11 +199,10 @@
 				createGroupsNavigation: function() {
 					var itemTemplate,
 						items,
-						svgUrl,
 						imgUrl,
 						useAttr;
 
-					if ( CKEDITOR.env.ie && !CKEDITOR.env.edge ) {
+					if ( !this.editor.plugins.emoji.isSVGSupported() ) {
 						imgUrl = CKEDITOR.getUrl( this.plugin.path + 'assets/iconsall.png' );
 
 						itemTemplate = new CKEDITOR.template(
@@ -224,10 +226,9 @@
 							}
 						}, '' );
 					} else {
-						svgUrl = CKEDITOR.getUrl( this.plugin.path + 'assets/iconsall.svg' );
 						// iOS has problem with reading `href` attribute, that's why,
 						// its necessary to use `xlink:href` even its deprecated: https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/xlink:href
-						useAttr = CKEDITOR.env.safari ? 'xlink:href="' + svgUrl + '#{svgId}"' : 'href="' + svgUrl + '#{svgId}"';
+						useAttr = CKEDITOR.env.safari ? 'xlink:href="#{svgId}"' : 'href="#{svgId}"';
 
 						itemTemplate = new CKEDITOR.template(
 							'<li class="cke_emoji-navigation_item" data-cke-emoji-group="{group}"><a href="#" title="{name}" draggable="false" _cke_focus="1">' +
@@ -342,14 +343,13 @@
 						'</div>';
 				},
 				getLoupeIcon: function() {
-					var loupeSvgUrl = CKEDITOR.getUrl( this.plugin.path + 'assets/iconsall.svg' ),
-						loupePngUrl = CKEDITOR.getUrl( this.plugin.path + 'assets/iconsall.png' ),
+					var loupePngUrl = CKEDITOR.getUrl( this.plugin.path + 'assets/iconsall.png' ),
 						useAttr;
 
-					if ( CKEDITOR.env.ie && !CKEDITOR.env.edge ) {
+					if ( !this.editor.plugins.emoji.isSVGSupported() ) {
 						return '<span class="cke_emoji-search_loupe" aria-hidden="true" style="background-image:url(' + loupePngUrl + ');"></span>';
 					} else {
-						useAttr = CKEDITOR.env.safari ? 'xlink:href="' + loupeSvgUrl + '#cke4-icon-emoji-10"' : 'href="' + loupeSvgUrl + '#cke4-icon-emoji-10"';
+						useAttr = CKEDITOR.env.safari ? 'xlink:href="#cke4-icon-emoji-10"' : 'href="#cke4-icon-emoji-10"';
 						return '<svg viewBox="0 0 34 34" role="img" aria-hidden="true" class="cke_emoji-search_loupe"><use ' + useAttr + '></use></svg>';
 					}
 				},
@@ -379,10 +379,11 @@
 					return arrTools.reduce(
 						items,
 						function( acc, item ) {
+							addEncodedName( item );
 							return acc + emojiTpl.output( {
 									symbol: htmlEncode( item.symbol ),
 									id: htmlEncode( item.id ),
-									name: htmlEncode( item.id.replace( /::.*$/, ':' ).replace( /^:|:$/g, '' ).replace( /_/g, ' ' ) ),
+									name: item.name,
 									group: htmlEncode( item.group ),
 									keywords: htmlEncode( ( item.keywords || [] ).join( ',' ) )
 								} );
@@ -529,6 +530,26 @@
 						return element.equals( item );
 					} );
 				},
+
+				// To avoid CORS issues due to XML-based SVG icons, they should be loaded into the panel document.
+				// This method ensures that the icons are loaded locally.
+				loadSVGNavigationIcons: function() {
+					if ( !this.editor.plugins.emoji.isSVGSupported() ) {
+						return;
+					}
+
+					var doc = this.blockElement.getDocument();
+
+					CKEDITOR.ajax.load( CKEDITOR.getUrl( this.plugin.path + 'assets/iconsall.svg' ), function( html ) {
+						var container = new CKEDITOR.dom.element( 'div' );
+
+						container.addClass( 'cke_emoji-navigation_icons' );
+						container.setHtml( html );
+
+						doc.getBody().append( container );
+					} );
+				},
+
 				addEmojiToGroups: function() {
 					var groupObj = {};
 					arrTools.forEach( this.groups, function( group ) {
@@ -545,7 +566,7 @@
 
 	CKEDITOR.plugins.add( 'emoji', {
 		requires: 'autocomplete,textmatch,ajax,panelbutton,floatpanel',
-		lang: 'en', // %REMOVE_LINE_CORE%
+		lang: 'cs,da,de,de-ch,el,en,en-au,et,fa,fr,gl,hr,hu,it,nl,pl,pt-br,sk,sr,sr-latn,sv,tr,uk,zh,zh-cn', // %REMOVE_LINE_CORE%
 		icons: 'emojipanel',
 		hidpi: true,
 
@@ -599,8 +620,9 @@
 					editor._.emoji.autocomplete = new CKEDITOR.plugins.autocomplete( editor, {
 						textTestCallback: getTextTestCallback(),
 						dataCallback: dataCallback,
-						itemTemplate: '<li data-id="{id}" class="cke_emoji-suggestion_item">{symbol} {id}</li>',
-						outputTemplate: '{symbol}'
+						itemTemplate: '<li data-id="{id}" class="cke_emoji-suggestion_item"><span>{symbol}</span> {name}</li>',
+						outputTemplate: '{symbol}',
+						followingSpace: editor.config.emoji_followingSpace
 					} );
 				}
 
@@ -641,6 +663,7 @@
 								return a.id > b.id ? 1 : -1;
 							}
 						} );
+					data = arrTools.map( data, addEncodedName );
 					callback( data );
 				}
 			} );
@@ -655,8 +678,19 @@
 				new EmojiDropdown( editor, this );
 			}
 
+		},
+
+		isSVGSupported: function() {
+			return !CKEDITOR.env.ie || CKEDITOR.env.edge;
 		}
 	} );
+
+	function addEncodedName( item ) {
+		if ( !item.name ) {
+			item.name = htmlEncode( item.id.replace( /::.*$/, ':' ).replace( /^:|:$/g, '' ) );
+		}
+		return item;
+	}
 } )();
 
 /**
@@ -704,3 +738,13 @@
  * @cfg {String} [emoji_emojiListUrl='plugins/emoji/emoji.json']
  * @member CKEDITOR.config
  */
+
+/**
+ * Indicates if a following space should be added after inserted match into an editor.
+ *
+ * @since 4.20.0
+ * @cfg {Boolean} [emoji_followingSpace=false]
+ * @member CKEDITOR.config
+ */
+
+CKEDITOR.config.emoji_followingSpace = false;
