@@ -1,9 +1,9 @@
-﻿/*
-Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or http://ckeditor.com/license
+/*
+Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
+For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'format', 'bn', {
-	label: 'ফন্ট ফরমেট',
+	label: 'ধরন-প্রকৃতি',
 	panelTitle: 'ফন্ট ফরমেট',
 	tag_address: 'ঠিকানা',
 	tag_div: 'শীর্ষক (DIV)',
