@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'link', 'fa', {
@@ -8,38 +8,39 @@ CKEDITOR.plugins.setLang( 'link', 'fa', {
 	advisoryContentType: 'نوع محتوای کمکی',
 	advisoryTitle: 'عنوان کمکی',
 	anchor: {
-		toolbar: 'گنجاندن/ویرایش لنگر',
-		menu: 'ویژگی​های لنگر',
-		title: 'ویژگی​های لنگر',
-		name: 'نام لنگر',
+		toolbar: 'گنجاندن/ویرایش لینک',
+		menu: 'ویرایش لینک',
+		title: 'ویژگی​های لینک',
+		name: 'نام لینک',
 		errorName: 'لطفا نام لنگر را بنویسید',
-		remove: 'حذف لنگر'
+		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
+		remove: 'حذف لینک'
 	},
 	anchorId: 'با شناسهٴ المان',
-	anchorName: 'با نام لنگر',
+	anchorName: 'با نام لینک ',
 	charset: 'نویسه​گان منبع پیوند شده',
-	cssClasses: 'کلاس​های شیوه​نامه(Stylesheet)',
-	download: 'Force Download', // MISSING
+	cssClasses: 'کلاس​های شیوه​نامه (Style sheet)',
+	download: 'بارگیری اجباری',
 	displayText: 'نمایش متن',
 	emailAddress: 'نشانی پست الکترونیکی',
 	emailBody: 'متن پیام',
 	emailSubject: 'موضوع پیام',
 	id: 'شناسه',
 	info: 'اطلاعات پیوند',
-	langCode: 'جهت​نمای زبان',
+	langCode: 'کد زبان',
 	langDir: 'جهت​نمای زبان',
 	langDirLTR: 'چپ به راست (LTR)',
 	langDirRTL: 'راست به چپ (RTL)',
 	menu: 'ویرایش پیوند',
 	name: 'نام',
-	noAnchors: '(در این سند لنگری دردسترس نیست)',
+	noAnchors: '(در این سند لینکی دردسترس نیست)',
 	noEmail: 'لطفا نشانی پست الکترونیکی را بنویسید',
-	noUrl: 'لطفا URL پیوند را بنویسید',
-	noTel: 'Please type the phone number', // MISSING
+	noUrl: 'لطفا آدرس پیوند را بنویسید',
+	noTel: 'لطفا شماره تلفن را وارد کنید',
 	other: '<سایر>',
-	phoneNumber: 'Phone number', // MISSING
+	phoneNumber: 'شماره تلفن',
 	popupDependent: 'وابسته (Netscape)',
-	popupFeatures: 'ویژگی​های پنجرهٴ پاپاپ',
+	popupFeatures: 'ویژگی​های پنجره ی پاپاپ',
 	popupFullScreen: 'تمام صفحه (IE)',
 	popupLeft: 'موقعیت چپ',
 	popupLocationBar: 'نوار موقعیت',
@@ -50,19 +51,19 @@ CKEDITOR.plugins.setLang( 'link', 'fa', {
 	popupToolbar: 'نوار ابزار',
 	popupTop: 'موقعیت بالا',
 	rel: 'وابستگی',
-	selectAnchor: 'یک لنگر برگزینید',
+	selectAnchor: 'یک لینک برگزینید',
 	styles: 'شیوه (style)',
 	tabIndex: 'نمایهٴ دسترسی با برگه',
 	target: 'مقصد',
-	targetFrame: '<فریم>',
-	targetFrameName: 'نام فریم مقصد',
+	targetFrame: '<قاب>',
+	targetFrameName: 'نام قاب مقصد',
 	targetPopup: '<پنجرهٴ پاپاپ>',
-	targetPopupName: 'نام پنجرهٴ پاپاپ',
+	targetPopupName: 'نام پنجره ی پاپاپ',
 	title: 'پیوند',
 	toAnchor: 'لنگر در همین صفحه',
 	toEmail: 'پست الکترونیکی',
-	toUrl: 'URL',
-	toPhone: 'Phone', // MISSING
+	toUrl: 'آدرس',
+	toPhone: 'تلفن',
 	toolbar: 'گنجاندن/ویرایش پیوند',
 	type: 'نوع پیوند',
 	unlink: 'برداشتن پیوند',
