@@ -1,5 +1,5 @@
 ﻿/*
-Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'link', 'tr', {
@@ -13,6 +13,7 @@ CKEDITOR.plugins.setLang( 'link', 'tr', {
 		title: 'Bağlantı Özellikleri',
 		name: 'Bağlantı Adı',
 		errorName: 'Lütfen bağlantı için ad giriniz',
+		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
 		remove: 'Bağlantıyı Kaldır'
 	},
 	anchorId: 'Eleman Kimlik Numarası ile',
@@ -35,9 +36,9 @@ CKEDITOR.plugins.setLang( 'link', 'tr', {
 	noAnchors: '(Bu belgede hiç çapa yok)',
 	noEmail: 'Lütfen E-posta adresini yazın',
 	noUrl: 'Lütfen Link URL\'sini yazın',
-	noTel: 'Please type the phone number', // MISSING
+	noTel: 'Lütfen telefon numaranızı yazınız',
 	other: '<diğer>',
-	phoneNumber: 'Phone number', // MISSING
+	phoneNumber: 'Telefon numarası',
 	popupDependent: 'Bağımlı (Netscape)',
 	popupFeatures: 'Yeni Açılan Pencere Özellikleri',
 	popupFullScreen: 'Tam Ekran (IE)',
@@ -62,7 +63,7 @@ CKEDITOR.plugins.setLang( 'link', 'tr', {
 	toAnchor: 'Bu sayfada çapa',
 	toEmail: 'E-Posta',
 	toUrl: 'URL',
-	toPhone: 'Phone', // MISSING
+	toPhone: 'Telefon',
 	toolbar: 'Link Ekle/Düzenle',
 	type: 'Link Türü',
 	unlink: 'Köprü Kaldır',
