@@ -1,5 +1,5 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
@@ -29,8 +29,22 @@
 	 * @member CKEDITOR.plugins.pastetools.filters.common
 	 */
 	plug.rules = function( html, editor, filter ) {
+		var availableFonts = getMatchingFonts( editor );
 		return {
 			elements: {
+				'^': function( element ) {
+					removeSuperfluousStyles( element );
+					// Don't use "attributeNames", because those rules are applied after elements.
+					// Normalization is required at the very begininng.
+					normalizeAttributesName( element );
+				},
+
+				'span': function( element ) {
+					if ( element.hasClass( 'Apple-converted-space' ) ) {
+						return new CKEDITOR.htmlParser.text( ' ' );
+					}
+				},
+
 				'table': function( element ) {
 					element.filterChildren( filter );
 
@@ -58,10 +72,12 @@
 					Style.convertStyleToPx( element );
 
 				},
+
 				'tr': function( element ) {
 					// Attribues are moved to 'td' elements.
 					element.attributes = {};
 				},
+
 				'td': function( element ) {
 					var ascendant = element.getAscendant( 'table' ),
 						ascendantStyle = tools.parseCssText( ascendant.attributes.style, true );
@@ -115,7 +131,6 @@
 						} else {
 							Style.setStyle( element, border, borderStyle.toString() );
 						}
-
 					}
 
 					Style.mapCommonStyles( element );
@@ -124,6 +139,12 @@
 
 					Style.createStyleStack( element, filter, editor,
 						/margin|text\-align|padding|list\-style\-type|width|height|border|white\-space|vertical\-align|background/i );
+				},
+
+				'font': function( element ) {
+					if ( element.attributes.face && availableFonts ) {
+						element.attributes.face = replaceWithMatchingFont( element.attributes.face, availableFonts );
+					}
 				}
 			}
 		};
@@ -186,10 +207,10 @@
 					Style.setStyle( element, 'vertical-align', value );
 				},
 				width: function( value ) {
-					Style.setStyle( element, 'width', value + 'px' );
+					Style.setStyle( element, 'width', fixValue( value ) );
 				},
 				height: function( value ) {
-					Style.setStyle( element, 'height', value + 'px' );
+					Style.setStyle( element, 'height', fixValue( value ) );
 				}
 			} );
 		},
@@ -744,6 +765,238 @@
 
 	plug.parseShorthandMargins = parseShorthandMargins;
 
+	/**
+	 * Namespace containing all the helper functions to work with [RTF](https://interoperability.blob.core.windows.net/files/Archive_References/%5bMSFT-RTF%5d.pdf).
+	 *
+	 * @private
+	 * @since 4.16.0
+	 * @member CKEDITOR.plugins.pastetools.filters.common
+	 */
+	plug.rtf = {
+		/**
+		 * Get all groups from the RTF content with the given name.
+		 *
+		 * ```js
+		 * var rtfContent = '{\\rtf1\\some\\control\\words{\\group content}{\\group content}{\\whatever {\\subgroup content}}}',
+		 * 	groups = CKEDITOR.plugins.pastetools.filters.common.rtf.getGroups( rtfContent, '(group|whatever)' );
+		 *
+		 * console.log( groups );
+		 *
+		 * // Result of the console.log:
+		 * // [
+		 * // 	{"start":25,"end":41,"content":"{\\group content}"},
+		 * // 	{"start":41,"end":57,"content":"{\\group content}"},
+		 * // 	{"start":57,"end":88,"content":"{\\whatever {\\subgroup content}}"}
+		 * // ]
+		 * ```
+		 *
+		 * @private
+		 * @since 4.16.0
+		 * @param {String} rtfContent
+		 * @param {String} groupName Group name to find. It can be a regex-like string.
+		 * @returns {CKEDITOR.plugins.pastetools.filters.common.rtf.GroupInfo[]}
+		 * @member CKEDITOR.plugins.pastetools.filters.common.rtf
+		 */
+		getGroups: function( rtfContent, groupName ) {
+			var groups = [],
+				current,
+				from = 0;
+
+			while ( current = plug.rtf.getGroup( rtfContent, groupName, {
+				start: from
+			} ) ) {
+				from = current.end;
+
+				groups.push( current );
+			}
+
+			return groups;
+		},
+
+		/**
+		 * Remove all groups from the RTF content with the given name.
+		 *
+		 * ```js
+		 * var rtfContent = '{\\rtf1\\some\\control\\words{\\group content}{\\group content}{\\whatever {\\subgroup content}}}',
+		 * 	rtfWithoutGroups = CKEDITOR.plugins.pastetools.filters.common.rtf.removeGroups( rtfContent, '(group|whatever)' );
+		 *
+		 * console.log( rtfWithoutGroups ); // {\rtf1\some\control\words}
+		 * ```
+		 *
+		 * @private
+		 * @since 4.16.0
+		 * @param {String} rtfContent
+		 * @param {String} groupName Group name to find. It can be a regex-like string.
+		 * @returns {String} RTF content without the removed groups.
+		 * @member CKEDITOR.plugins.pastetools.filters.common.rtf
+		 */
+		removeGroups: function( rtfContent, groupName ) {
+			var current;
+
+			while ( current = plug.rtf.getGroup( rtfContent, groupName ) ) {
+				var beforeContent = rtfContent.substring( 0, current.start ),
+					afterContent = rtfContent.substring( current.end );
+
+				rtfContent = beforeContent + afterContent;
+			}
+
+			return rtfContent;
+		},
+
+		/**
+		 * Get the group from the RTF content with the given name.
+		 *
+		 * Groups are recognized thanks to being in `{\<name>}` format.
+		 *
+		 * ```js
+		 * var rtfContent = '{\\rtf1\\some\\control\\words{\\group content1}{\\group content2}{\\whatever {\\subgroup content}}}',
+		 * 	firstGroup = CKEDITOR.plugins.pastetools.filters.common.rtf.getGroup( rtfContent, '(group|whatever)' ),
+		 * 	lastGroup = CKEDITOR.plugins.pastetools.filters.common.rtf.getGroup( rtfContent, '(group|whatever)', {
+		 * 		start: 50
+		 * 	} );
+		 *
+		 * console.log( firstGroup ); // {"start":25,"end":42,"content":"{\\group content1}"}
+		 * console.log( lastGroup ); // {"start":59,"end":90,"content":"{\\whatever {\\subgroup content}}"}
+		 * ```
+		 *
+		 * @private
+		 * @since 4.16.0
+		 * @param {String} content RTF content.
+		 * @param {String} groupName Group name to find. It can be a regex-like string.
+		 * @param {Object} options Additional options.
+		 * @param {Number} options.start String index on which the search should begin.
+		 * @returns {CKEDITOR.plugins.pastetools.filters.common.rtf.GroupInfo}
+		 * @member CKEDITOR.plugins.pastetools.filters.common.rtf
+		 */
+		getGroup: function( content, groupName, options ) {
+			// This function is in fact a very primitive RTF parser.
+			// It iterates over RTF content and search for the last } in the group
+			// by keeping track of how many elements are open using a stack-like method.
+			var open = 0,
+				// Despite the fact that we search for only one group,
+				// the global modifier is used to be able to manipulate
+				// the starting index of the search. Without g flag it's impossible.
+				startRegex = new RegExp( '\\{\\\\' + groupName, 'g' ),
+				group,
+				i,
+				current;
+
+			options = CKEDITOR.tools.object.merge( {
+				start: 0
+			}, options || {} );
+
+			startRegex.lastIndex = options.start;
+			group = startRegex.exec( content );
+
+			if ( !group ) {
+				return null;
+			}
+
+			i = group.index;
+			current = content[ i ];
+
+			do {
+				// Every group start has format of {\. However there can be some whitespace after { and before /.
+				// Additionally we need to filter also curly braces from the content – fortunately they are escaped.
+				var isValidGroupStart = current === '{' && getPreviousNonWhitespaceChar( content, i ) !== '\\' &&
+					getNextNonWhitespaceChar( content, i ) === '\\',
+					isValidGroupEnd = current === '}' && getPreviousNonWhitespaceChar( content, i ) !== '\\' &&
+						open > 0;
+
+				if ( isValidGroupStart ) {
+					open++;
+				} else if ( isValidGroupEnd ) {
+					open--;
+				}
+
+				current = content[ ++i ];
+			} while ( current && open > 0 );
+
+			return {
+				start: group.index,
+				end: i,
+				content: content.substring( group.index, i )
+			};
+		},
+
+		/**
+		 * Get group content.
+		 *
+		 * The content starts with the first character that is not a part of
+		 * control word or subgroup.
+		 *
+		 * ```js
+		 * var group = '{\\group{\\subgroup subgroupcontent} group content}',
+		 * 	groupContent = CKEDITOR.plugins.pastetools.filters.common.rtf.extractGroupContent( group );
+		 *
+		 * console.log( groupContent ); // "group content"
+		 * ```
+		 *
+		 * @private
+		 * @since 4.16.0
+		 * @param {String} group Whole group string.
+		 * @returns {String} Extracted group content.
+		 * @member CKEDITOR.plugins.pastetools.filters.common.rtf
+		 */
+		extractGroupContent: function( group ) {
+			var groupName = getGroupName( group ),
+				controlWordsRegex = /^\{(\\[\w-]+\s*)+/g,
+				// Sometimes content follows the last subgroup without any space.
+				// We need to add it to correctly parse the whole thing.
+				subgroupWithousSpaceRegex = /\}([^{\s]+)/g;
+
+			group = group.replace( subgroupWithousSpaceRegex, '} $1' );
+			// And now remove all subgroups that are not the actual group.
+			group = plug.rtf.removeGroups( group, '(?!' + groupName + ')' );
+			// Remove all control words and trim the whitespace at the beginning
+			// that could be introduced by preserving space after last subgroup.
+			group = CKEDITOR.tools.trim( group.replace( controlWordsRegex, '' ) );
+
+			// What's left is group content with } at the end.
+			return group.replace( /}$/, '' );
+		}
+	};
+
+	function getGroupName( group ) {
+		var groupNameRegex = /^\{\\(\w+)/,
+			groupName = group.match( groupNameRegex );
+
+		if ( !groupName ) {
+			return null;
+		}
+
+		return groupName[ 1 ];
+	}
+
+	function getPreviousNonWhitespaceChar( content, index ) {
+		return getNonWhitespaceChar( content, index, -1 );
+	}
+
+	function getNextNonWhitespaceChar( content, index ) {
+		return getNonWhitespaceChar( content, index, 1 );
+	}
+
+	function getNonWhitespaceChar( content, startIndex, direction ) {
+		var index = startIndex + direction,
+			current = content[ index ],
+			whiteSpaceRegex = /[\s]/;
+
+		while ( current && whiteSpaceRegex.test( current ) ) {
+			index = index + direction;
+			current = content[ index ];
+		}
+
+		return current;
+	}
+
+
+	function fixValue( value ) {
+		// Add 'px' only for values which are not ended with %
+		var endsWithPercent = /%$/;
+
+		return endsWithPercent.test( value ) ? value : value + 'px';
+	}
+
 	// Same as createStyleStack, but instead of styles - stack attributes.
 	function createAttributeStack( element, filter ) {
 		var i,
@@ -797,6 +1050,129 @@
 		}
 	}
 
+	function removeSuperfluousStyles( element ) {
+		var resetStyles = [
+				'background-color:transparent',
+				'background:transparent',
+				'background-color:none',
+				'background:none',
+				'background-position:initial initial',
+				'background-repeat:initial initial',
+				'caret-color',
+				'font-family:-webkit-standard',
+				'font-variant-caps',
+				'letter-spacing:normal',
+				'orphans',
+				'widows',
+				'text-transform:none',
+				'word-spacing:0px',
+				'-webkit-text-size-adjust:auto',
+				'-webkit-text-stroke-width:0px',
+				'text-indent:0px',
+				'margin-bottom:0in'
+			];
+
+		var styles = CKEDITOR.tools.parseCssText( element.attributes.style ),
+			styleName,
+			styleString;
+
+		for ( styleName in styles ) {
+			styleString = styleName + ':' + styles[ styleName ];
+
+			if ( CKEDITOR.tools.array.some( resetStyles, function( val ) {
+				return styleString.substring( 0, val.length ).toLowerCase() === val;
+			} ) ) {
+				delete styles[ styleName ];
+				continue;
+			}
+		}
+
+		styles = CKEDITOR.tools.writeCssText( styles );
+
+		if ( styles !== '' ) {
+			element.attributes.style = styles;
+		} else {
+			delete element.attributes.style;
+		}
+	}
+
+	function getMatchingFonts( editor ) {
+		var fontNames = editor.config.font_names,
+			validNames = [];
+
+		if ( !fontNames || !fontNames.length ) {
+			return false;
+		}
+
+		validNames = CKEDITOR.tools.array.map( fontNames.split( ';' ), function( value ) {
+			// Font can have a short name at the begining. It's necessary to remove it, to apply correct style.
+			if ( value.indexOf( '/' ) === -1 ) {
+				return value;
+			}
+
+			return value.split( '/' )[ 1 ];
+		} );
+
+		return validNames.length ? validNames : false;
+	}
+
+	function replaceWithMatchingFont( fontValue, availableFonts ) {
+		var fontParts = fontValue.split( ',' ),
+			matchingFont = CKEDITOR.tools.array.find( availableFonts, function( font ) {
+				for ( var i = 0; i < fontParts.length; i++ ) {
+					if ( font.indexOf( CKEDITOR.tools.trim( fontParts[ i ] ) ) === -1 ) {
+						return false;
+					}
+				}
+
+				return true;
+			} );
+
+		return matchingFont || fontValue;
+	}
+
+	function normalizeAttributesName( element ) {
+		if ( element.attributes.bgcolor ) {
+			var styles = CKEDITOR.tools.parseCssText( element.attributes.style );
+
+			if ( !styles[ 'background-color' ] ) {
+				styles[ 'background-color' ] = element.attributes.bgcolor;
+
+				element.attributes.style = CKEDITOR.tools.writeCssText( styles );
+			}
+		}
+	}
+
+	/**
+	 * Virtual class that illustrates group info
+	 * returned by {@link CKEDITOR.plugins.pastetools.filters.common.rtf#getGroup} method.
+	 *
+	 * @since 4.16.0
+	 * @class CKEDITOR.plugins.pastetools.filters.common.rtf.GroupInfo
+	 * @abstract
+	 */
+
+	/**
+	 * String index, on which the group starts.
+	 *
+	 * @property {Number} start
+	 * @member CKEDITOR.plugins.pastetools.filters.common.rtf.GroupInfo
+	 */
+
+	/**
+	 * String index, on which the group ends.
+	 *
+	 * @property {Number} end
+	 * @member CKEDITOR.plugins.pastetools.filters.common.rtf.GroupInfo
+	 */
+
+	/**
+	 * The whole group, including control words and subgroups.
+	 *
+	 * @property {String} content
+	 * @member CKEDITOR.plugins.pastetools.filters.common.rtf.GroupInfo
+	 */
+
 	/**
 	 * Whether to ignore all font-related formatting styles, including:
 	 *
