@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'table', 'fr', {
@@ -27,6 +27,8 @@ CKEDITOR.plugins.setLang( 'table', 'fr', {
 		borderColor: 'Couleur de bordure',
 		data: 'Données',
 		header: 'En-tête',
+		columnHeader: 'Column Header', // MISSING
+		rowHeader: 'Row Header', // MISSING
 		yes: 'Oui',
 		no: 'Non',
 		invalidWidth: 'La largeur de la cellule doit être un nombre.',
@@ -50,7 +52,7 @@ CKEDITOR.plugins.setLang( 'table', 'fr', {
 	headersColumn: 'Première colonne',
 	headersNone: 'Aucun',
 	headersRow: 'Première ligne',
-	heightUnit: 'height unit', // MISSING
+	heightUnit: 'unité de hauteur',
 	invalidBorder: 'La taille de la bordure doit être un nombre.',
 	invalidCellPadding: 'La marge interne des cellules doit être un nombre positif.',
 	invalidCellSpacing: 'L\'espacement entre les cellules doit être un nombre positif.',
