@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'table', 'hu', {
@@ -27,6 +27,8 @@ CKEDITOR.plugins.setLang( 'table', 'hu', {
 		borderColor: 'Keret színe',
 		data: 'Adat',
 		header: 'Fejléc',
+		columnHeader: 'Column Header', // MISSING
+		rowHeader: 'Row Header', // MISSING
 		yes: 'Igen',
 		no: 'Nem',
 		invalidWidth: 'A szélesség mezőbe csak számokat írhat.',
@@ -50,7 +52,7 @@ CKEDITOR.plugins.setLang( 'table', 'hu', {
 	headersColumn: 'Első oszlop',
 	headersNone: 'Nincsenek',
 	headersRow: 'Első sor',
-	heightUnit: 'height unit', // MISSING
+	heightUnit: 'Magasság egység',
 	invalidBorder: 'A szegélyméret mezőbe csak számokat írhat.',
 	invalidCellPadding: 'A cella belső margó mezőbe csak számokat írhat.',
 	invalidCellSpacing: 'A cella térköz mezőbe csak számokat írhat.',
