@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'table', 'pl', {
@@ -27,6 +27,8 @@ CKEDITOR.plugins.setLang( 'table', 'pl', {
 		borderColor: 'Kolor obramowania',
 		data: 'Dane',
 		header: 'Nagłówek',
+		columnHeader: 'Column Header', // MISSING
+		rowHeader: 'Row Header', // MISSING
 		yes: 'Tak',
 		no: 'Nie',
 		invalidWidth: 'Szerokość komórki musi być liczbą.',
@@ -50,7 +52,7 @@ CKEDITOR.plugins.setLang( 'table', 'pl', {
 	headersColumn: 'Pierwsza kolumna',
 	headersNone: 'Brak',
 	headersRow: 'Pierwszy wiersz',
-	heightUnit: 'height unit', // MISSING
+	heightUnit: 'jednostka wysokości',
 	invalidBorder: 'Wartość obramowania musi być liczbą.',
 	invalidCellPadding: 'Dopełnienie komórek musi być liczbą dodatnią.',
 	invalidCellSpacing: 'Odstęp pomiędzy komórkami musi być liczbą dodatnią.',
