@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'table', 'sr-latn', {
@@ -27,6 +27,8 @@ CKEDITOR.plugins.setLang( 'table', 'sr-latn', {
 		borderColor: 'Boja okvira',
 		data: 'Podatak',
 		header: 'Zaglavlje',
+		columnHeader: 'Zaglavlje kolone',
+		rowHeader: 'Zaglavlje reda',
 		yes: 'Da',
 		no: 'Nе',
 		invalidWidth: 'U polje širina možete upisati samo brojeve. ',
@@ -50,7 +52,7 @@ CKEDITOR.plugins.setLang( 'table', 'sr-latn', {
 	headersColumn: 'Prva kolona',
 	headersNone: 'Nema',
 	headersRow: 'Prvi red',
-	heightUnit: 'height unit', // MISSING
+	heightUnit: 'Jedinica visine',
 	invalidBorder: 'Veličina okvira mora biti broj.',
 	invalidCellPadding: 'Padding polja mora biti pozitivan broj.',
 	invalidCellSpacing: 'Razmak između ćelija mora biti pozitivan broj.',
