@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'table', 'sr', {
@@ -27,6 +27,8 @@ CKEDITOR.plugins.setLang( 'table', 'sr', {
 		borderColor: 'Боја оквира',
 		data: 'Податак',
 		header: 'Наслов',
+		columnHeader: 'Заглавље колоне',
+		rowHeader: 'Заглавље реда',
 		yes: 'Да',
 		no: 'Не',
 		invalidWidth: 'У поље ширина можете уписати само бројеве.',
@@ -50,7 +52,7 @@ CKEDITOR.plugins.setLang( 'table', 'sr', {
 	headersColumn: 'Прва колона',
 	headersNone: 'Нема',
 	headersRow: 'Први ред',
-	heightUnit: 'height unit', // MISSING
+	heightUnit: 'Јединица висине',
 	invalidBorder: 'Величина ивице треба да буде цифра.',
 	invalidCellPadding: 'Пуњење ћелије треба да буде позитивна цифра.',
 	invalidCellSpacing: 'Размак ћелије треба да буде позитивна цифра.',
