@@ -1,8 +1,8 @@
 /**
- * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 CKEDITOR.plugins.setLang( 'widget', 'el', {
 	'move': 'Κάνετε κλικ και σύρετε το ποντίκι για να μετακινήστε',
-	'label': '%1 widget' // MISSING
+	'label': '%1 widget'
 } );
